<?php    
/**
 * Swiftone functions and definitions
 *
 * @package Swiftone
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'swiftone_setup' ) ) : 
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function swiftone_setup() {
	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'swiftone', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support('woocommerce');
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header', array( 
		'default-text-color' => false,
		'header-text' => false,
	) );
	add_theme_support( 'title-tag' );	
	add_theme_support( 'custom-logo', array(
		'height'      => 65,
		'width'       => 280,
		'flex-height' => true,
	) );		
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'swiftone' ),		
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
} 
endif; // swiftone_setup
add_action( 'after_setup_theme', 'swiftone_setup' );

function swiftone_widgets_init() { 	
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'swiftone' ),
		'description'   => __( 'Appears on blog page sidebar', 'swiftone' ),
		'id'            => 'sidebar-1',		
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
}
add_action( 'widgets_init', 'swiftone_widgets_init' );


function swiftone_font_url(){
		$font_url = '';		
		
		/* Translators: If there are any character that are not
		* supported by Roboto, trsnalate this to off, do not
		* translate into your own language.
		*/
		$roboto = _x('on','roboto:on or off','swiftone');	
		
		if('off' !== $roboto ){
			$font_family = array();			
			if('off' !== $roboto){
				$font_family[] = 'Roboto:300,400,600,700,800,900';
			}						
			$query_args = array(
				'family'	=> urlencode(implode('|',$font_family)),
			);			
			$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
		}
		
	return $font_url;
	}


function swiftone_scripts() {
	wp_enqueue_style('swiftone-font', swiftone_font_url(), array());
	wp_enqueue_style( 'swiftone-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'swiftone-editor-style', get_template_directory_uri()."/editor-style.css" );
	wp_enqueue_style( 'nivo-slider', get_template_directory_uri()."/css/nivo-slider.css" );
	wp_enqueue_style( 'swiftone-main-style', get_template_directory_uri()."/css/responsive.css" );		
	wp_enqueue_style( 'swiftone-default-style', get_template_directory_uri()."/css/styledefault.css" );
	wp_enqueue_script( 'jquery-nivo', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	wp_enqueue_script( 'swiftone-custom-js', get_template_directory_uri() . '/js/custom.js' );	
		

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'swiftone_scripts' );

function swiftone_ie_stylesheet(){
	global $wp_styles;
	
	/** Load our IE-only stylesheet for all versions of IE.
	*   <!--[if lt IE 9]> ... <![endif]-->
	*
	*  Note: It is also possible to just check and see if the $is_IE global in WordPress is set to true before
	*  calling the wp_enqueue_style() function. If you are trying to load a stylesheet for all browsers
	*  EXCEPT for IE, then you would HAVE to check the $is_IE global since WordPress doesn't have a way to
	*  properly handle non-IE conditional comments.
	*/
	wp_enqueue_style('swiftone_ie', get_template_directory_uri().'/css/ie.css', array('swiftone_style'));
	$wp_styles->add_data('swiftone_ie','conditional','IE');
	}
add_action('wp_enqueue_scripts','swiftone_ie_stylesheet');


define('swiftone_protheme_url','https://www.gracethemes.com/themes/unique-wordpress-theme/','swiftone');
define('swiftone_theme_doc','https://www.gracethemes.com/documentation/swiftone-doc/#homepage-lite','swiftone');
define('swiftone_live_demo','https://gracethemes.com/demo/swiftone/','swiftone');


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template for about theme.
 */
require get_template_directory() . '/inc/about-themes.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


 if ( ! function_exists( 'swiftone_the_custom_logo' ) ) :
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 * @since  Swiftone 1.2
 */
function swiftone_the_custom_logo() {
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}
endif;

// get slug by id
function swiftone_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}